@@ -8,6 +8,7 @@ mod admin_update_program_fee;
 mod admin_update_worker_fee;
 mod daemon_create;
 mod daemon_invoke;
+mod daemon_widthdraw;
 mod fee_collect;
 mod health_check;
 mod task_cancel;
@@ -24,6 +25,7 @@ pub use admin_update_program_fee::*;
 pub use admin_update_worker_fee::*;
 pub use daemon_create::*;
 pub use daemon_invoke::*;
+pub use daemon_widthdraw::*;
 pub use fee_collect::*;
 pub use health_check::*;
 pub use task_cancel::*;
